# unsatfit

unsatfit is a Python library for optimizing parameters of [functions of soil hydraulic properties](https://doi.org/10.1002/vzj2.20168) (water retention function and unsaturated hydraulic conductivity function).

- [Document](https://sekika.github.io/unsatfit/)

## SWRC Fit

SWRC Fit is a web interface which uses unsatfit and determines parameters for water retention function.

- [SWRC Fit](https://seki.webmasters.gr.jp/swrc/)
